@@ -1,6 +1,14 @@
 -- complain if script is sourced in psql, rather than via CREATE EXTENSION
 \echo Use "CREATE EXTENSION pgaudit" to load this file.\quit
 
+-- Drop old triggers and functions
+drop event trigger if exists pgaudit_ddl_command_end;
+drop function if exists pgaudit_ddl_command_end();
+
+drop event trigger if exists pgaudit_sql_drop;
+drop function if exists pgaudit_sql_drop();
+
+-- Create triggers and functions with security definer and search_path
 CREATE FUNCTION pgaudit_ddl_command_end()
 	RETURNS event_trigger
 	SECURITY DEFINER
